@@ -12,22 +12,29 @@ fi
 # reload the gnulib code if possible
 PATH=/usr/local/src/gnu/gnulib:${PATH}
 mods="
+	alloca
+	dirent
 	faccessat
 	fdopendir
 	fstatat
 	futimens
 	getline
+	getopt-posix
+	inttypes
 	mkdirat
 	openat
 	progname
 	readlinkat
 	renameat
 	stat-time
+	stpcpy
+	strcasestr-simple
 	strncat
 	symlinkat
 	sys_stat
 	unlinkat
 	utimensat
+	vasprintf-posix
 "
 v gnulib-tool \
 	--source-base=autotools/gnulib --m4-base=autotools/m4 \
