@@ -22,9 +22,7 @@
 #include "copy_file.c"
 #include "safe_io.c"
 #include "xchdir.c"
-#include "xgetcwd.c"
 #include "xmkdir.c"
-#include "xreadlink.c"
 #include "xregex.c"
 #include "xsystem.c"
 #include "xarray.c"
