@@ -1,5 +1,6 @@
 /* Emulate `mkdir -p -m MODE PATH` */
-static int mkdir_p_at(int dfd, const char *path, mode_t mode)
+static int
+mkdir_p_at(int dfd, const char *path, mode_t mode)
 {
 	char *_p, *p, *s;
 
@@ -35,13 +36,15 @@ static int mkdir_p_at(int dfd, const char *path, mode_t mode)
 
 	return 0;
 }
-static int mkdir_p(const char *path, mode_t mode)
+static int
+mkdir_p(const char *path, mode_t mode)
 {
 	return mkdir_p_at(AT_FDCWD, path, mode);
 }
 
 /* Emulate `rm -rf PATH` */
-_q_static int rm_rf_at(int dfd, const char *path)
+static int
+rm_rf_at(int dfd, const char *path)
 {
 	int subdfd;
 	DIR *dir;
@@ -62,8 +65,14 @@ _q_static int rm_rf_at(int dfd, const char *path)
 		if (!strcmp(de->d_name, ".") || !strcmp(de->d_name, ".."))
 			continue;
 		if (unlinkat(subdfd, de->d_name, 0) == -1) {
-			if (errno != EISDIR)
-				errp("could not unlink %s", de->d_name);
+			if (unlikely(errno != EISDIR)) {
+				struct stat st;
+				/* above is a linux short-cut, we really just want to
+				 * know whether we're really with a directory or not */
+				if (fstatat(subdfd, de->d_name, &st, 0) != 0 ||
+						!(st.st_mode & S_IFDIR))
+					errp("could not unlink %s", de->d_name);
+			}
 			rm_rf_at(subdfd, de->d_name);
 			unlinkat(subdfd, de->d_name, AT_REMOVEDIR);
 		}
@@ -75,7 +84,8 @@ _q_static int rm_rf_at(int dfd, const char *path)
 	return 0;
 }
 
-_q_static int rm_rf(const char *path)
+static int
+rm_rf(const char *path)
 {
 	rm_rf_at(AT_FDCWD, path);
 
@@ -91,7 +101,8 @@ _q_static int rm_rf(const char *path)
 	return -1;
 }
 
-_q_static int rmdir_r_at(int dfd, const char *path)
+static int
+rmdir_r_at(int dfd, const char *path)
 {
 	size_t len;
 	char *p, *e;
@@ -113,7 +124,8 @@ _q_static int rmdir_r_at(int dfd, const char *path)
 }
 
 /*
-_q_static int rmdir_r(const char *path)
+static int
+rmdir_r(const char *path)
 {
 	return rmdir_r_at(AT_FDCWD, path);
 }
