@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2014 Gentoo Foundation
+ * Copyright 2005-2018 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
@@ -126,7 +126,7 @@ int q_main(int argc, char **argv)
 #elif defined(__sun) && defined(__SVR4)
 		prog = getexecname();
 		rret = strlen(prog);
-		if (rret > sizeof(buf) - 1) {
+		if ((size_t)rret > sizeof(buf) - 1) {
 			rret = -1;
 		} else {
 			strncpy(buf, prog, rret);
