@@ -39,7 +39,7 @@ static const char qlop_desc[] =
 	"The --date option can take a few forms:\n"
 	"  -d '# <day|week|month|year>[s] [ago]'  (e.g. '3 days ago')\n"
 	"Or using strptime(3) formats:\n"
-	"  -d '2015-12-25'           (detected as %F)\n"
+	"  -d '2015-12-25'           (detected as %Y-%m-%d)\n"
 	"  -d '1459101740'           (detected as %s)\n"
 	"  -d '%d.%m.%Y|25.12.2015'  (format is specified)";
 #define qlop_usage(ret) usage(ret, QLOP_FLAGS, qlop_long_opts, qlop_opts_help, qlop_desc, lookup_applet_idx("qlop"))
@@ -733,7 +733,7 @@ parse_date(const char *sdate, time_t *t)
 	} else {
 		/* Handle automatic formats:
 		 * - "12315128"   -> %s
-		 * - "2015-12-24" -> %F (same as %Y-%m-%d
+		 * - "2015-12-24" -> %Y-%m-%d
 		 * - human readable format (see below)
 		 */
 		size_t len = strspn(sdate, "0123456789-");
@@ -742,7 +742,7 @@ parse_date(const char *sdate, time_t *t)
 			if (strchr(sdate, '-') == NULL)
 				fmt = "%s";
 			else
-				fmt = "%F";
+				fmt = "%Y-%m-%d";
 
 			s = strptime(sdate, fmt, &tm);
 			if (s == NULL || s[0] != '\0')
@@ -758,8 +758,17 @@ parse_date(const char *sdate, time_t *t)
 			char ago[len];
 			int ret = sscanf(sdate, "%lu %s %s", &num, dur, ago);
 
-			if (ret < 2)
-				return false;
+			if (ret < 2) {
+				if (strcmp(sdate, "today") == 0) {
+					num = 1;
+					snprintf(dur, len, "%s", "day");
+				} else if (strcmp(sdate, "yesterday") == 0) {
+					num = 2;
+					snprintf(dur, len, "%s", "day");
+				} else {
+					return false;
+				}
+			}
 			if (ret == 3 && strcmp(ago, "ago") != 0)
 				return false;
 
