@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2014 Gentoo Foundation
+ * Copyright 2005-2018 Gentoo Foundation
  * Distributed under the terms of the GNU General Public License v2
  *
  * Copyright 2005-2010 Ned Ludd        - <solar@gentoo.org>
@@ -21,8 +21,8 @@ static struct option const qsearch_long_opts[] = {
 };
 static const char * const qsearch_opts_help[] = {
 	"List the descriptions of every package in the cache",
-	"Use the portage cache (default)",
-	"Use the portage ebuild tree",
+	"Use the portage cache",
+	"Use the portage ebuild tree (default)",
 	"Regex search package basenames",
 	"Regex search package descriptions",
 	"Only show package name",
@@ -101,9 +101,10 @@ qsearch_ebuild_ebuild(int overlay_fd, const char *ebuild, const char *search_me,
 	}
 
 	char *buf = NULL;
-	size_t buflen, linelen;
-	while ((linelen = getline(&buf, &buflen, ebuildfp)) != -1) {
-		if (linelen <= search_len)
+	int linelen;
+	size_t buflen;
+	while ((linelen = getline(&buf, &buflen, ebuildfp)) >= 0) {
+		if ((size_t)linelen <= search_len)
 			continue;
 		if (strncmp(buf, search_var, search_len) != 0)
 			continue;
@@ -194,10 +195,11 @@ int qsearch_main(int argc, char **argv)
 			continue;
 		}
 
-		size_t buflen, linelen;
+		int linelen;
+		size_t buflen;
 		char *buf = NULL;
-		while ((linelen = getline(&buf, &buflen, fp)) != -1) {
-			rmspace_len(buf, linelen);
+		while ((linelen = getline(&buf, &buflen, fp)) >= 0) {
+			rmspace_len(buf, (size_t)linelen);
 			if (!buf[0])
 				continue;
 
