@@ -34,9 +34,10 @@ main() {
 	m
 	m check
 
+	# LSan needs sudo, which we don't use at the moment
 	# Debug build w/ASAN and such enabled.
-	m debug
-	m check
+	#m debug
+	#m check
 
 	# Do scans last as they like to dirty the tree and some tests
 	# expect a clean tree (like code style checks).
